summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/msn/msninvitation.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/msn/msninvitation.h')
-rw-r--r--kopete/protocols/msn/msninvitation.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kopete/protocols/msn/msninvitation.h b/kopete/protocols/msn/msninvitation.h
index 90010dc3..d8b48116 100644
--- a/kopete/protocols/msn/msninvitation.h
+++ b/kopete/protocols/msn/msninvitation.h
@@ -17,7 +17,7 @@
#ifndef MSNINVITATION_H
#define MSNINVITATION_H
-#include <qstring.h>
+#include <tqstring.h>
#include "kopete_export.h"
@@ -27,7 +27,7 @@ class QObject;
* @author Olivier Goffart
*
* The invitation is the base class which handle an MSN invitation.
* The implemented class must to herits from QObject too.
* You can accept the invitation by catching @ref MSNProtocol::invitation() signals
* or create one and insert it to a kmm with @ref MSNChatSession::initInvitation()
* you can add action with @ref Kopete::Plugin::customChatActions()
@@ -41,14 +41,14 @@ public:
* @param applicationID is the exadecimal id of the invitation
* @param applicationName is a i18n'ed string of the name of the application
*/
- MSNInvitation(bool incoming,const QString &applicationID , const QString &applicationName);
+ MSNInvitation(bool incoming,const TQString &applicationID , const TQString &applicationName);
virtual ~MSNInvitation();
/**
* @internal
* it is a reject invitation because the invitation is not implemented
*/
- static QCString unimplemented(long unsigned int cookie);
+ static TQCString unimplemented(long unsigned int cookie);
/**
* you can set manualy the cookie. note that a cookie is automatically generated when a new
@@ -71,24 +71,24 @@ public:
* the default implementation return the common begin.
* You can also set the state to Invited (the default implementation do that)
*/
- virtual QString invitationHead();
+ virtual TQString invitationHead();
/**
* This is the reject invitation string
* @param rejectcode is the code, it can be "REJECT" or "TIMEOUT"
*/
- QCString rejectMessage(const QString & rejectcode = "REJECT");
+ TQCString rejectMessage(const TQString & rejectcode = "REJECT");
/**
* reimplement this method. it is called when an invitation message with the invitation's cookie is received
* the default implementation parse the cookie, or the reject message
*/
- virtual void parseInvitation(const QString& invitation);
+ virtual void parseInvitation(const TQString& invitation);
/**
* return the qobject (this)
*/
- virtual QObject* object()=0;
+ virtual TQObject* object()=0;
//signals:
/**
* reimplement this as a signal, and emit it when the invitation has to be destroyed.
@@ -116,8 +116,8 @@ public:
protected:
bool m_incoming;
long unsigned int m_cookie;
- QString m_applicationId;
- QString m_applicationName;
+ TQString m_applicationId;
+ TQString m_applicationName;
State m_state;
@@ -27,7 +27,7 @@ class QObject;
*
* The invitation is the base class which handle an MSN invitation.
- * The implemented class must to herits from QObject too.
+ * The implemented class must to herits from TQObject too.
* You can accept the invitation by catching @ref MSNProtocol::invitation() signals
* or create one and insert it to a kmm with @ref MSNChatSession::initInvitation()